@@ -10,3 +10,6 @@ from .config import _load_xpmerge_from_csv, _load_offset_from_csv, \
 
 from . import dispersion_function
 from .dispersion_function import pwl_to_wl, wl_to_pwl, pwl_range, wl_range
+
+from . import server
+from .server import data_release, gaia_server
